@@ -43,3 +43,9 @@ def select():
         new_db.display()
     except Exception as e:
         print('Error occurred:', e)
+
+def display():
+    try:
+        badsql.load('test').display()
+    except Exception as e:
+        print('Error occurred:', e)
